@@ -1,6 +1,10 @@
 """Top-level package for stupidb."""
 
+import importlib.metadata
+
 from stupidb.aggregation import Window  # noqa: F401
 from stupidb.api import *  # noqa: F401,F403
 
-__version__ = "6.0.2"
+__version__ = importlib.metadata.version(__name__)
+
+del importlib
