@@ -1,7 +1,7 @@
-from stupidb.indextree import IndexTree
+from stupidb.associative.indextree import IndexTree
 
 
-def test_tree_repr_fanout_2():
+def test_tree_repr_fanout_2() -> None:
     tree = IndexTree(height=3, fanout=2)
     expected = """\
 |-- 0
@@ -14,7 +14,7 @@ def test_tree_repr_fanout_2():
     assert repr(tree) == expected
 
 
-def test_tree_repr_fanout_4():
+def test_tree_repr_fanout_4() -> None:
     tree = IndexTree(height=2, fanout=4)
     expected = """\
 |-- 0
@@ -25,6 +25,6 @@ def test_tree_repr_fanout_4():
     assert repr(tree) == expected
 
 
-def test_parent_of_root():
+def test_parent_of_root() -> None:
     tree = IndexTree(height=2, fanout=2)
     assert tree.parent(0) == 0
