@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from stupidb.protocols import Comparable
 
 
@@ -5,14 +7,16 @@ class CustomComparable(Comparable):
     def __init__(self, value: float) -> None:
         self.value = value
 
-    def __eq__(self, other) -> bool:
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, CustomComparable):
+            return NotImplemented
         return self.value == other.value
 
-    def __lt__(self, other) -> bool:
+    def __lt__(self, other: CustomComparable) -> bool:
         return self.value < other.value
 
 
-def test_comparable_implements_methods_eq():
+def test_comparable_implements_methods_eq() -> None:
     comp = CustomComparable(1.0)
     comp2 = CustomComparable(1.0)
     assert comp == comp2
@@ -23,7 +27,7 @@ def test_comparable_implements_methods_eq():
     assert comp >= comp2
 
 
-def test_comparable_implements_methods_ne():
+def test_comparable_implements_methods_ne() -> None:
     comp = CustomComparable(1.0)
     comp2 = CustomComparable(2.0)
     assert comp != comp2
